@@ -59,6 +59,9 @@ FAILEDOPERATION_DBOPERATIONACTIONERROR = 'FailedOperation.DBOperationActionError
 # 删除审计失败。
 FAILEDOPERATION_DELETEAUDITFAILERROR = 'FailedOperation.DeleteAuditFailError'
 
+# 查询数据库代理失败。
+FAILEDOPERATION_DESCRIBEPROXYGROUPERROR = 'FailedOperation.DescribeProxyGroupError'
+
 # 获取权限错误。
 FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'
 
@@ -77,9 +80,15 @@ FAILEDOPERATION_NOTDELAYRO = 'FailedOperation.NotDelayRo'
 # 执行的权限修改操作非法。您可以参照产品文档，了解当前实例支持哪些权限修改操作，如有疑问，请您咨询客服进行处理。
 FAILEDOPERATION_PRIVILEGEDATAILLEGAL = 'FailedOperation.PrivilegeDataIllegal'
 
+# 数据库代理状态异常。
+FAILEDOPERATION_PROXYGROUPSTATUSERROR = 'FailedOperation.ProxyGroupStatusError'
+
 # 查询日志失败。
 FAILEDOPERATION_QUERYLOGERROR = 'FailedOperation.QueryLogError'
 
+# 代理创建中或则已存在，请勿重复创建。
+FAILEDOPERATION_REPEATCREATEPROXYERROR = 'FailedOperation.RepeatCreateProxyError'
+
 # 后台请求服务异常，请您联系客服解决。
 FAILEDOPERATION_RESPONSEVALUEERROR = 'FailedOperation.ResponseValueError'
 
@@ -350,6 +359,9 @@ OPERATIONDENIED_AUDITPOLICYEXISTERROR = 'OperationDenied.AuditPolicyExistError'
 # 审计策略不存在。
 OPERATIONDENIED_AUDITPOLICYNOTEXISTERROR = 'OperationDenied.AuditPolicyNotExistError'
 
+# 审计策略数量超限。
+OPERATIONDENIED_AUDITPOLICYOVERQUOTAERROR = 'OperationDenied.AuditPolicyOverQuotaError'
+
 # 审计规则删除失败。
 OPERATIONDENIED_AUDITRULEDELETEERROR = 'OperationDenied.AuditRuleDeleteError'
 
